## dbt-tests-adapter 1.19.4 - November 19, 2025

### Features

- Add base test class for python aggregate functions ([#1432](https://github.com/dbt-labs/dbt-adapters/issues/1432))
- Add base test case for sql aggregate functions ([#1432](https://github.com/dbt-labs/dbt-adapters/issues/1432))
